# MachXO2 Boards

The {py:mod}`torii_boards.lattice.machxo2` module provides a collection of Lattice MachXO2 FPGA development boards, they are based off the Torii {py:class}`MachXO2Platform <torii.platform.vendor.lattice.machxo_2_3l.MachXO2Platform>` platform and support the [Diamond] toolchain.

```{eval-rst}
.. autoclass:: torii_boards.lattice.machxo2.TinyFPGAAX1Platform
  :members:

.. autoclass:: torii_boards.lattice.machxo2.TinyFPGAAX2Platform
  :members:
```

[Diamond]: https://www.latticesemi.com/latticediamond
